import {Schema, ObjectId, model} from "mongoose";
import { fieldEncryption } from "mongoose-field-encryption";
import * as process from "process";

export interface IAccount {
    id: ObjectId,
    username: string,
    email: string,
    password: string,
    verified: boolean,
    verificationSecret: number | undefined,
    totpSecret?: string
}

const AccountSchema = new Schema<IAccount>({
    username: {
        type: String,
        required: true
    },
    email: {
        type: String,
        required: true,
    },
    password: {
        type: String,
        required: true
    },
    verificationSecret: {
        type: Number,
        default: () =>  Math.floor(Math.random() * (999999 - 100000 + 1)) + 100000
    },
    verified: {
        type: Boolean,
        default: false
    },
    totpSecret: String
});

AccountSchema.plugin(fieldEncryption, {
    fields: ["username", "email", "password", "totpSecret"],
    secret: process.env.ENC_KEY,
    saltGenerator: () => process.env.SIG_KEY
});

export const Account = model<IAccount>("accounts", AccountSchema);