import {model, ObjectId, Schema, Types} from "mongoose";
import encrypt from "mongoose-encryption";

export enum ILicenseMetaType {
    STRING
}

export interface ILicenseMeta {
    type: ILicenseMetaType,
    key: string,
    value: string
}

export interface ILicense {
    id: ObjectId,
    projectId: ObjectId,
    key: string,
    groups?: string[],
    permissions?: string[],
    meta?: ILicenseMeta[],
    expirationDate?: Date
}

const LicenseSchema = new Schema<ILicense>({
    projectId: {
        type: Types.ObjectId,
        required: true
    },
    key: {
        type: String,
        required: true
    },
    groups: [String],
    permissions: [String],
    meta: [Array],
    expirationDate: {
        type: Date,
        default: Date.now
    }
});

LicenseSchema.plugin(encrypt, {
    encryptionKey: process.env.ENC_KEY,
    signingKey: process.env.SIG_KEY
});

export const License = model<ILicense>("licenses", LicenseSchema);